@@ -12,10 +12,10 @@ from emtable import Table
 
 RELION_JOB_FAILURE_FILENAME = "RELION_JOB_EXIT_FAILURE"
 RELION_JOB_SUCCESS_FILENAME = "RELION_JOB_EXIT_SUCCESS"
-CONDA_ENV = ". ~/rc/conda.rc && conda activate cinderella-0.6.0"
+CONDA_ENV = ". /home/gsharov/rc/conda.rc && conda activate cinderella-0.7.0"
 CINDERELLA_PREDICT = "sp_cinderella_predict.py"
 CINDERELLA_GEN_MODEL = "/home/gsharov/soft/cryolo/relion_lmb_cl2d_model_based_on_cinderella.h5"
-DEBUG = 1
+DEBUG = 0
 
 
 def run_job(project_dir, args):
@@ -37,6 +37,7 @@ def run_job(project_dir, args):
     modelstar = in_parts.replace("_data.star", "_model.star")
     refstable = Table(fileName=getPath(modelstar), tableName='model_classes')
     refstack = refstable[0].rlnReferenceImage.split("@")[-1]
+    nrCls = int(refstable[-1].rlnReferenceImage.split("@")[0])
 
     if DEBUG:
         print("Found input class averages stack: %s" % refstack)
@@ -74,6 +75,10 @@ def run_job(project_dir, args):
         print("Parsing output file: %s\nGood classes: %s" % (outpath, goodcls))
 
     if len(goodcls) == 0:
+        print("No good classes found. Job stopped.")
+        end = time.time()
+        diff = end - start
+        print("Job duration = %dh %dmin %dsec \n" % (diff // 3600, diff // 60 % 60, diff % 60))
         open(RELION_JOB_FAILURE_FILENAME, "w").close()
         exit(1)
 
@@ -96,9 +101,16 @@ def run_job(project_dir, args):
         optics.writeStar(f, tableName="optics")
         out_ptcls.writeStar(f, tableName="particles")
 
+    # Create backup_selection.star for results visualization
+    sel = Table(columns=['rlnSelected'])
+    for i in range(1, nrCls + 1):
+        sel.addRow(1 if i in goodcls else 0)
+    with open(getPath("backup_selection.star"), "w") as f:
+        sel.writeStar(f, tableName="")
+
     end = time.time()
     diff = end - start
-    print("Job duration = %dh %dmin %dsec \n" % (diff//3600, diff//60%60, diff%60))
+    print("Job duration = %dh %dmin %dsec \n" % (diff//3600, diff//60 % 60, diff % 60))
 
 
 def main():
